# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 18:30:54 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
misc.update(
    {
        "InstallerSection_Private": objc.createStructType(
            "InstallerSection_Private", b"{InstallerSection_Private=}", []
        ),
        "InstallerState_Private": objc.createStructType(
            "InstallerState_Private", b"{InstallerState_Private=}", []
        ),
        "InstallerPane_Private": objc.createStructType(
            "InstallerPane_Private", b"{InstallerPane_Private=}", []
        ),
    }
)
constants = """$InstallerState_Choice_CustomLocation$InstallerState_Choice_Identifier$InstallerState_Choice_Installed$"""
enums = """$InstallerDirectionBackward@1$InstallerDirectionForward@0$InstallerDirectionUndefined@2$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"InstallerPane", b"gotoNextPane", {"retval": {"type": "Z"}})
    r(b"InstallerPane", b"gotoPreviousPane", {"retval": {"type": "Z"}})
    r(b"InstallerPane", b"nextEnabled", {"retval": {"type": "Z"}})
    r(b"InstallerPane", b"previousEnabled", {"retval": {"type": "Z"}})
    r(b"InstallerPane", b"setNextEnabled:", {"arguments": {2: {"type": "Z"}}})
    r(b"InstallerPane", b"setPreviousEnabled:", {"arguments": {2: {"type": "Z"}}})
    r(b"InstallerPane", b"shouldExitPane:", {"retval": {"type": "Z"}})
    r(b"InstallerSection", b"gotoPane:", {"retval": {"type": "Z"}})
    r(b"InstallerSection", b"shouldLoad", {"retval": {"type": "Z"}})
    r(b"InstallerState", b"installStarted", {"retval": {"type": "Z"}})
    r(b"InstallerState", b"installSucceeded", {"retval": {"type": "Z"}})
    r(b"InstallerState", b"licenseAgreed", {"retval": {"type": "Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
